@@ -61,6 +61,7 @@ struct _BijiNoteObjClass
   void          (*set_html)          (BijiNoteObj *note, gchar *html);
   void          (*save_note)         (BijiNoteObj *note);
   gboolean      (*archive)           (BijiNoteObj *note);
+  gboolean      (*is_trashed)        (BijiNoteObj *note);
   gboolean      (*can_format)        (BijiNoteObj *note);
 };
 
@@ -103,13 +104,6 @@ gboolean         biji_note_obj_set_create_date               (BijiNoteObj* n ,
 void             biji_note_obj_set_all_dates_now             (BijiNoteObj *note);
 
 
-int              get_note_status                             (BijiNoteObj* n);
-
-
-void             set_note_status                             (BijiNoteObj* n,
-                                                              int status) ;
-
-
 gboolean         biji_note_obj_get_rgba                      (BijiNoteObj *n,
                                                               GdkRGBA *rgba) ;
 
@@ -127,6 +121,9 @@ void             note_obj_set_is_template                    (BijiNoteObj *n,
                                                               gboolean is_template);
 
 
+gboolean         biji_note_obj_is_trashed                    (BijiNoteObj *self);
+
+
 void             biji_note_obj_save_note                     (BijiNoteObj *self);
 
 
@@ -151,6 +148,9 @@ gboolean         biji_note_obj_set_title                     (BijiNoteObj* note_
 gboolean         biji_note_obj_is_template                   (BijiNoteObj *note);
 
 
+gboolean         biji_note_obj_is_trashed                    (BijiNoteObj *note);
+
+
 GtkWidget       *biji_note_obj_open                          (BijiNoteObj *note);
 
 
