@@ -304,6 +304,30 @@ on_note_color_changed (BijiNoteObj *note, BijiWebkitEditor *self)
     set_editor_color (GTK_WIDGET (self), &color);
 }
 
+
+static void
+open_url ( const char *uri)
+{
+  gtk_show_uri (gdk_screen_get_default (),
+                uri,
+                gtk_get_current_event_time (),
+                NULL);
+}
+
+
+gboolean
+on_navigation_request                  (WebKitWebView             *web_view,
+                                        WebKitWebFrame            *frame,
+                                        WebKitNetworkRequest      *request,
+                                        WebKitWebNavigationAction *navigation_action,
+                                        WebKitWebPolicyDecision   *policy_decision,
+                                        gpointer                   user_data)
+{
+  webkit_web_policy_decision_ignore (policy_decision);
+  open_url (webkit_network_request_get_uri (request));
+  return TRUE;
+}
+
 static void
 biji_webkit_editor_constructed (GObject *obj)
 {
@@ -330,6 +354,12 @@ biji_webkit_editor_constructed (GObject *obj)
 
   webkit_web_view_load_string (view, body, "application/xhtml+xml", NULL, NULL);
 
+
+  /* Do not be a browser */
+  g_signal_connect (view, "navigation-policy-decision-requested",
+                    G_CALLBACK (on_navigation_request), NULL);
+
+
   /* Drag n drop */
   GtkTargetList *targets = webkit_web_view_get_copy_target_list (view);
   gtk_target_list_add_image_targets (targets, 0, TRUE);
